@@ -46,10 +46,10 @@ class comscore_omnicom_database:
         
         if isinstance(endpoint, type(None)):
      
-            self.engine_str = 'postgres://' + str(self.user) + ':' + str(self.password) + '@dsdk-v0p1-annalect.clf6bikxcquu.us-east-1.redshift.amazonaws.com:5439/dsdk'
+            self.engine_str = 'postgresql://' + str(self.user) + ':' + str(self.password) + '@dsdk-v0p1-annalect.clf6bikxcquu.us-east-1.redshift.amazonaws.com:5439/dsdk'
         
         else:
-            self.engine_str = 'postgres://' + str(self.user) + ':' + str(self.password) + str(endpoint)
+            self.engine_str = 'postgresql://' + str(self.user) + ':' + str(self.password) + str(endpoint)
         
         self.engine = create_engine(self.engine_str)
         self.connection = self.engine.connect()
@@ -939,4 +939,159 @@ class comscore_omnicom_database:
                 path_file = input('define your personal path to save the file: ')
                 short_frame_a.to_csv(path_file + 'bayesianinference_sites_prob_{}_{}_{}.csv'.format(domain.replace('.', '-'), start_date, end_date))
 
-            return short_frame_a, dataframe_probs_a
\ No newline at end of file
+            return short_frame_a, dataframe_probs_a
+    
+    def costumer_journey_site(self, country = None, age_group = False,
+                                domain = None, time_spent = 350, like_domain = None, interval_time = None,
+                                start_date = None, end_date = None, saved = False):
+
+        """A function that generates the path traveled by a user who entered your site, based on a time interval.
+
+        Note:
+            To use this method, you must have previously logged in.
+
+        Args:
+            country (str, required): Select the country code on which you want to create a query. 
+                Possible options are: ['us','ar', 'au','br', 'ca', 'cl', 'co', 'hk', 'id', 'in', 'mx', 'my', 'nz', 'sg', 'tw']
+
+            start_date (str, optional): Select from which date you want to see your data.
+                The default is 2019-01-01
+
+            end_date (str, optional): Select the maximum date to consult.
+                The default value is 2019-06-01
+
+            domain (str, optional): The main domain on which we want to overlap
+
+            time_spent (int, required): The minimum amount of time a user has to spend on the site and the competitor's site to be examined.
+                The default value is 350.
+
+        Returns:
+            DataFrame: If the process occurs correctly, you will get a dataframe with all the required data.
+        
+        Raises:
+            TypeError: If any of the arguments is sent with the wrong data type, a TypeError will be obtained, 
+                also if some mandatory value is not delivered to the function.
+
+            """
+        
+        query = """
+
+            WITH guid_tables AS ( ---- QUERY TO CREATE AUDIENCE 
+            select guid, domain,
+            min(CONVERT(datetime,dateadd(s, event_time,'2000-01-01')) at time zone 'utc' at time zone 'clst') as target_time,
+            target_time + INTERVAL '{interval_time}' as positive_interval_time,
+            target_time - INTERVAL '{interval_time}' as negative_interval_time
+            from spectrum_comscore.clickstream_{country}
+            
+            where domain = '{domain_in}'
+            {event_detail_like}
+            and calendar_date between '{start_date_in}' and '{end_date_in}'
+            group by 1,2
+            
+            ),
+
+            demographics AS ( ---- QUERY TO EXTRACT DEMOGRAPHICS
+            select 
+            {age_value} as age_column,
+            *
+            from guid_tables a 
+            join spectrum_comscore.person_demographics_{country} b
+            on a.guid = b.person_id
+            ),
+
+            final_table as ( --- COMPLETE QUERY
+            select
+            a.guid,
+            b.gender,
+            b.age_column,
+            b.hh_income,
+            b.children_present,
+                case a.event
+                when 'SEARCH' then a.event_detail
+                when 'WEB' then a.domain
+                when 'PRODUCT VIEW' then a.event_detail
+                when 'SOCIAL' then a.event_detail
+                when 'VIDEO' then a.event_detail
+                    else a.event_detail 
+                    end as domain,
+            b.target_time,
+                CONVERT(datetime,dateadd(s, a.event_time,'2000-01-01')) at time zone 'utc' at time zone 'clst' as timestamp,
+                count(a.guid) as visit_count,
+                sum(a.time_spent) as seconds_spent
+            from spectrum_comscore.clickstream_{country} a
+            join demographics b 
+                using (guid)
+            where time_spent >= {time_spent_greater_than}
+            and timestamp >= b.negative_interval_time and timestamp <= b.positive_interval_time
+            group by 1,2,3,4,5,6,7,8)
+
+            select * from final_table
+            """
+
+        if isinstance(country, type(None)):
+            error = 'Define your country'
+            raise TypeError(error)
+        
+        if isinstance(domain, type(None)):
+            error = 'Define your domain'
+            raise TypeError(error)
+            
+        if isinstance(like_domain, type(None)):
+            domainlike = ''
+        else:
+            if not isinstance(like_domain, str):
+                error = 'domain like is not a string'
+                raise TypeError(error)
+            else:
+                domainlike = "and event_detail SIMILAR TO '%%{}%%'".format(like_domain)
+            
+        if isinstance(start_date, type(None)):
+            start_date = '2019-01-01'
+            print('The preset date was defined, which starts from January 1, 2019')
+        
+        if isinstance(end_date, type(None)):
+            end_date = '2019-06-01'
+            print('The preset date was defined, which starts from January 1, 2019')
+        
+        if not isinstance(interval_time, str):
+            error = 'interval_time like is not a string'
+            raise TypeError(error)
+        else:
+            pass
+
+        if age_group:
+            age_group_value = """
+            CASE
+                    WHEN age > 13 AND age <= 17 THEN '13-17'
+                    WHEN age > 17 AND age <= 34 THEN '18-34'
+                    WHEN age > 34 AND age <= 54 THEN '35-54'
+                    WHEN age > 54 THEN '55+'
+                ELSE
+                    'Undetermined'
+                END
+            """
+        else:
+            age_group_value = """ age """
+        
+
+        sentence = query.format(interval_time = interval_time,
+                                start_date_in = start_date, 
+                                end_date_in = end_date,
+                                domain_in = domain,
+                                country = country, 
+                                event_detail_like = domainlike, 
+                                time_spent_greater_than = time_spent, 
+                                age_value = age_group_value
+                                )
+        
+        print(sentence + '\n')
+        dataframe = read_sql(sentence, con = self.connection)
+
+        dataframe['diff_timestamp'] = dataframe.timestamp - dataframe.target_time
+        dataframe.sort_values(['guid', 'diff_timestamp']).reset_index(drop = True, inplace = True)
+
+        if saved:
+            path_file = input('define your personal path to save the file: ')
+            dataframe.to_csv(path_file + 'journey_{}_{}_{}.csv'.format(domain.replace('.', '-'), start_date, end_date))
+        
+        return dataframe
\ No newline at end of file
